AccountLockerVaultCollectionItemFungible class

Constructors

AccountLockerVaultCollectionItemFungible({required AccountLockerVaultCollectionItemType type, required String resourceAddress, required String vaultAddress, required int lastUpdatedAtStateVersion, required String amount})
Returns a new AccountLockerVaultCollectionItemFungible instance.

Properties

amount String
String-encoded decimal representing the amount of a related fungible resource.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
lastUpdatedAtStateVersion int
The most recent state version underlying object was modified at.
getter/setter pair
resourceAddress String
Bech32m-encoded human readable version of the address.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type AccountLockerVaultCollectionItemType
getter/setter pair
vaultAddress String
Bech32m-encoded human readable version of the address.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) AccountLockerVaultCollectionItemFungible?
Returns a new AccountLockerVaultCollectionItemFungible instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<AccountLockerVaultCollectionItemFungible>
mapFromJson(dynamic json) Map<String, AccountLockerVaultCollectionItemFungible>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<AccountLockerVaultCollectionItemFungible>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.