NotSyncedUpError class

Constructors

NotSyncedUpError({required String type, required String requestType, required int currentSyncDelaySeconds, required int maxAllowedSyncDelaySeconds})
Returns a new NotSyncedUpError instance.

Properties

currentSyncDelaySeconds int
The current delay between the Gateway DB and the network ledger round timestamp.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
maxAllowedSyncDelaySeconds int
The maximum allowed delay between the Gateway DB and the network ledger round timestamp for this request_type.
getter/setter pair
requestType String
The request type that triggered this exception.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
The type of error. Each subtype may have its own additional structured fields.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) NotSyncedUpError?
Returns a new NotSyncedUpError instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<NotSyncedUpError>
mapFromJson(dynamic json) Map<String, NotSyncedUpError>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<NotSyncedUpError>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.