StateEntityDetailsOptIns class

Constructors

StateEntityDetailsOptIns({bool ancestorIdentities = false, bool componentRoyaltyConfig = false, bool componentRoyaltyVaultBalance = false, bool packageRoyaltyVaultBalance = false, bool nonFungibleIncludeNfids = false, List<String> explicitMetadata = const []})
Returns a new StateEntityDetailsOptIns instance.

Properties

ancestorIdentities bool
if set to true, ancestor addresses - parent_address, owner_address and global_address for entities are returned.
getter/setter pair
componentRoyaltyConfig bool
if set to true, royalty_config for component entities is returned.
getter/setter pair
componentRoyaltyVaultBalance bool
if set to true, royalty_vault_balance for component entities is returned.
getter/setter pair
explicitMetadata List<String>
allows specifying explicitly metadata properties which should be returned in response.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
nonFungibleIncludeNfids bool
if set to true, first page of non fungible ids are returned for each non fungible resource, with next_cursor which can be later used at /state/entity/page/non-fungible-vault/ids endpoint.
getter/setter pair
packageRoyaltyVaultBalance bool
if set to true, royalty_vault_balance for package entities is returned.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) StateEntityDetailsOptIns?
Returns a new StateEntityDetailsOptIns instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<StateEntityDetailsOptIns>
mapFromJson(dynamic json) Map<String, StateEntityDetailsOptIns>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<StateEntityDetailsOptIns>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.