StateEntityDetailsResponse class
Constructors
-
StateEntityDetailsResponse({required LedgerState ledgerState, List<
StateEntityDetailsResponseItem> items = const []}) - Returns a new StateEntityDetailsResponse instance.
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
-
items
↔ List<
StateEntityDetailsResponseItem> -
getter/setter pair
- ledgerState ↔ LedgerState
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → StateEntityDetailsResponse? -
Returns a new StateEntityDetailsResponse instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< StateEntityDetailsResponse> -
mapFromJson(
dynamic json) → Map< String, StateEntityDetailsResponse> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< StateEntityDetailsResponse> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.