StateEntityDetailsResponseComponentDetails class

Constructors

StateEntityDetailsResponseComponentDetails({required StateEntityDetailsResponseItemDetailsType type, String? packageAddress, required String blueprintName, required String blueprintVersion, Object? state, ComponentEntityRoleAssignments? roleAssignments, String? royaltyVaultBalance, ComponentRoyaltyConfig? royaltyConfig})
Returns a new StateEntityDetailsResponseComponentDetails instance.

Properties

blueprintName String
getter/setter pair
blueprintVersion String
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
packageAddress String?
Bech32m-encoded human readable version of the address.
getter/setter pair
roleAssignments ComponentEntityRoleAssignments?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
royaltyConfig ComponentRoyaltyConfig?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
royaltyVaultBalance String?
String-encoded decimal representing the amount of a related fungible resource.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state Object?
A representation of a component's inner state. If this entity is a GenericComponent, this field will be in a programmatic JSON structure (you can deserialize it as a ProgrammaticScryptoSborValue). Otherwise, for "native" components such as Account, Validator, AccessController, OneResourcePool, TwoResourcePool, and MultiResourcePool, this field will be a custom JSON model defined in the Core API schema.
getter/setter pair
type StateEntityDetailsResponseItemDetailsType
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) StateEntityDetailsResponseComponentDetails?
Returns a new StateEntityDetailsResponseComponentDetails instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<StateEntityDetailsResponseComponentDetails>
mapFromJson(dynamic json) Map<String, StateEntityDetailsResponseComponentDetails>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<StateEntityDetailsResponseComponentDetails>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.