StateEntityDetailsResponseNonFungibleResourceDetails class

Constructors

StateEntityDetailsResponseNonFungibleResourceDetails({required StateEntityDetailsResponseItemDetailsType type, required ComponentEntityRoleAssignments roleAssignments, required NonFungibleIdType nonFungibleIdType, required String totalSupply, required String totalMinted, required String totalBurned})
Returns a new StateEntityDetailsResponseNonFungibleResourceDetails instance.

Properties

hashCode int
The hash code for this object.
no setteroverride
nonFungibleIdType NonFungibleIdType
getter/setter pair
roleAssignments ComponentEntityRoleAssignments
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalBurned String
String-encoded decimal representing the amount of a related fungible resource.
getter/setter pair
totalMinted String
String-encoded decimal representing the amount of a related fungible resource.
getter/setter pair
totalSupply String
String-encoded decimal representing the amount of a related fungible resource.
getter/setter pair
type StateEntityDetailsResponseItemDetailsType
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) StateEntityDetailsResponseNonFungibleResourceDetails?
Returns a new StateEntityDetailsResponseNonFungibleResourceDetails instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<StateEntityDetailsResponseNonFungibleResourceDetails>
mapFromJson(dynamic json) Map<String, StateEntityDetailsResponseNonFungibleResourceDetails>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<StateEntityDetailsResponseNonFungibleResourceDetails>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.