StateEntityDetailsResponsePackageDetails class
Properties
-
blueprints
↔ PackageBlueprintCollection?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
-
codeHashHex
↔ String
-
Hex-encoded binary blob.
getter/setter pair
-
codeHex
↔ String
-
Hex-encoded binary blob.
getter/setter pair
-
codes
↔ PackageCodeCollection
-
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setteroverride
-
roleAssignments
↔ ComponentEntityRoleAssignments?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
-
royaltyVaultBalance
↔ String?
-
String-encoded decimal representing the amount of a related fungible resource.
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
schemas
↔ EntitySchemaCollection?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
-
type
↔ StateEntityDetailsResponseItemDetailsType
-
getter/setter pair
-
vmType
↔ PackageVmType
-
getter/setter pair