StateEntityNonFungibleResourceVaultsPageOptIns class

Constructors

StateEntityNonFungibleResourceVaultsPageOptIns({bool? nonFungibleIncludeNfids})
Returns a new StateEntityNonFungibleResourceVaultsPageOptIns instance.

Properties

hashCode int
The hash code for this object.
no setteroverride
nonFungibleIncludeNfids bool?
if set to true, first page of non fungible ids are returned for each non fungible resource, with cursor which can be later used at /state/entity/page/non-fungible-vault/ids endpoint.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) StateEntityNonFungibleResourceVaultsPageOptIns?
Returns a new StateEntityNonFungibleResourceVaultsPageOptIns instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<StateEntityNonFungibleResourceVaultsPageOptIns>
mapFromJson(dynamic json) Map<String, StateEntityNonFungibleResourceVaultsPageOptIns>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<StateEntityNonFungibleResourceVaultsPageOptIns>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.