StateNonFungibleIdsRequest class

Constructors

StateNonFungibleIdsRequest({LedgerStateSelector? atLedgerState, String? cursor, int? limitPerPage, required String resourceAddress})
Returns a new StateNonFungibleIdsRequest instance.

Properties

atLedgerState LedgerStateSelector?
getter/setter pair
cursor String?
This cursor allows forward pagination, by providing the cursor from the previous request.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
limitPerPage int?
The page size requested.
getter/setter pair
resourceAddress String
Bech32m-encoded human readable version of the address.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) StateNonFungibleIdsRequest?
Returns a new StateNonFungibleIdsRequest instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<StateNonFungibleIdsRequest>
mapFromJson(dynamic json) Map<String, StateNonFungibleIdsRequest>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<StateNonFungibleIdsRequest>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.