StateEntityFungibleResourceVaultsPageResponse class
Constructors
-
StateEntityFungibleResourceVaultsPageResponse({required LedgerState ledgerState, int? totalCount, String? nextCursor, List<
FungibleResourcesCollectionItemVaultAggregatedVaultItem> items = const [], required String address, required String resourceAddress}) - Returns a new StateEntityFungibleResourceVaultsPageResponse instance.
Properties
- address ↔ String
-
Bech32m-encoded human readable version of the address.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
-
items
↔ List<
FungibleResourcesCollectionItemVaultAggregatedVaultItem> -
getter/setter pair
- ledgerState ↔ LedgerState
-
getter/setter pair
- nextCursor ↔ String?
-
If specified, contains a cursor to query next page of the
itemscollection.getter/setter pair - resourceAddress ↔ String
-
Bech32m-encoded human readable version of the address.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalCount ↔ int?
-
Total number of items in underlying collection, fragment of which is available in
itemscollection.getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → StateEntityFungibleResourceVaultsPageResponse? -
Returns a new StateEntityFungibleResourceVaultsPageResponse instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< StateEntityFungibleResourceVaultsPageResponse> -
mapFromJson(
dynamic json) → Map< String, StateEntityFungibleResourceVaultsPageResponse> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< StateEntityFungibleResourceVaultsPageResponse> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.